## Tushare期权数据

1、Tushare期权交易所代码表

| 交易所名称 | 交易所代码 | 合约后缀 |
| --- | --- | --- |
| 郑州商品交易所 | CZCE | .ZCE |
| 上海期货交易所 | SHFE | .SHF |
| 大连商品交易所 | DCE | .DCE |
| 上海证券交易所 | SSE | .SH |
| 深圳证券交易所 | SZSE | .SZ |
| 中国金融期货交易所 | CFFEX | .CFX |

2、目前提供的数据列表

- 期权合约信息
- 期权日线行情